@@ -9,13 +9,51 @@ class CEM(Optimizer):
     This is the **base** (abstract) class for all `CEM` classes. Please use any of its instantiated subclasses to
     optimize the black-box problem at hand.
 
-    .. note:: `CEM` is a class of well-established, principled population-based optimizers, proposed originally
-       by Rubinstein, whose core idea is based on **Kullback–Leibler (or cross-entropy) minimization**.
+    .. note:: `CEM` is a class of **principled** population-based optimizers, proposed originally by Rubinstein,
+        whose core idea is based on **Kullback–Leibler (or cross-entropy) minimization**.
 
-       "CEM is not only based on fundamental principles (cross-entropy distance, maximum likelihood, etc.), but is
+       `"CEM is not only based on fundamental principles (cross-entropy distance, maximum likelihood, etc.), but is
        also very easy to program (with far fewer parameters than many other global optimization heuristics), and
        gives consistently accurate results, and is therefore worth considering when faced with a difficult
        optimization problem."---[Kroese et al., 2006, MCAP]
+       <https://link.springer.com/article/10.1007/s11009-006-9753-0>`_
+
+    Parameters
+    ----------
+    problem : dict
+              problem arguments with the following common settings (`keys`):
+                * 'fitness_function' - objective function to be **minimized** (`func`),
+                * 'ndim_problem'     - number of dimensionality (`int`),
+                * 'upper_boundary'   - upper boundary of search range (`array_like`),
+                * 'lower_boundary'   - lower boundary of search range (`array_like`).
+    options : dict
+              optimizer options with the following common settings (`keys`):
+                * 'max_function_evaluations' - maximum of function evaluations (`int`, default: `np.Inf`),
+                * 'max_runtime'              - maximal runtime to be allowed (`float`, default: `np.Inf`),
+                * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`);
+              and with the following particular settings (`keys`):
+                * 'sigma'         - initial global step-size, aka mutation strength (`float`),
+                * 'mean'          - initial (starting) point, aka mean of Gaussian search distribution (`array_like`),
+
+                  * if not given, it will draw a random sample from the uniform distribution whose search range is
+                    bounded by `problem['lower_boundary']` and `problem['upper_boundary']`.
+
+                * 'n_individuals' - number of individuals/samples (`int`, default: `1000`),
+                * 'n_parents'     - number of elitists (`int`, default: `200`),
+
+    Attributes
+    ----------
+    mean          : `array_like`
+                    initial (starting) point, aka mean of Gaussian search (mutation/sampling) distribution.
+    n_individuals : `int`
+                    number of individuals/samples.
+    n_parents     : `int`
+                    number of elitists.
+    sigma         : `float`
+                    initial global step-size, aka mutation strength.
+
+    Methods
+    -------
 
     References
     ----------
