@@ -1,6 +1,7 @@
 from pypop7.optimizers.ep.ep import EP
 from pypop7.optimizers.ep.cep import CEP
 from pypop7.optimizers.ep.fep import FEP
+from pypop7.optimizers.ep.lep import LEP
 
 
-__all__ = [EP, CEP, FEP]
+__all__ = [EP, CEP, FEP, LEP]
