@@ -10,10 +10,10 @@
     https://direct.mit.edu/evco/article-abstract/1/1/1/1092/An-Overview-of-Evolutionary-Algorithms-for
 
     Note that we first update individual step-sizes and then update offspring for each generation as the
-    same as the second paper (different from the first paper), in order to obtain fast local convergence.
+    same as the second paper (but different from the first paper), in order to obtain fast local convergence.
 
-    Luckily very close performance can be obtained on five benchmark functions by our source code. Therefore,
-    we argue that the **repeatability** of `CEP` can be well-documented (*at least partly*).
+    Luckily our code could repeat the data reported in the original paper *well*.
+    Therefore, we argue that the repeatability of `CEP` could be **well-documented** (*at least partly*).
 """
 import numpy as np
 
@@ -24,67 +24,63 @@ from pypop7.optimizers.ep.cep import CEP
 if __name__ == '__main__':
     ndim_problem = 30
 
-    problem = {'fitness_function': rastrigin,
-               'ndim_problem': ndim_problem,
-               'lower_boundary': -5.12*np.ones((ndim_problem,)),
-               'upper_boundary': 5.12*np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 5000*100,
-               'seed_rng': 0,  # undefined in the original paper
-               'sigma': 3.0}
-    cep = CEP(problem, options)
-    results = cep.optimize()
-    print(results['best_so_far_y'])
-    # 43.778146043621575
-    # vs 89 (from the original paper)
-
     problem = {'fitness_function': ackley,
                'ndim_problem': ndim_problem,
-               'lower_boundary': -32*np.ones((ndim_problem,)),
-               'upper_boundary': 32*np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 1500*100,
+               'lower_boundary': -32 * np.ones((ndim_problem,)),
+               'upper_boundary': 32 * np.ones((ndim_problem,))}
+    options = {'max_function_evaluations': 1500 * 100,
                'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     cep = CEP(problem, options)
     results = cep.optimize()
     print(results['best_so_far_y'])
-    # 1.157071658638206
-    # vs 9.2 (from the original paper)
+    # 1.8999348918498282 vs 8.882487
 
     problem = {'fitness_function': sphere,
                'ndim_problem': ndim_problem,
-               'lower_boundary': -100*np.ones((ndim_problem,)),
-               'upper_boundary': 100*np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 1500*100,
+               'lower_boundary': -100 * np.ones((ndim_problem,)),
+               'upper_boundary': 100 * np.ones((ndim_problem,))}
+    options = {'max_function_evaluations': 1500 * 100,
                'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     cep = CEP(problem, options)
     results = cep.optimize()
     print(results['best_so_far_y'])
-    # 0.0035835937017922037
-    # vs 2.2e-4 (from the original paper)
+    # 0.031063134665527244 vs 0.00095
 
     problem = {'fitness_function': step,
                'ndim_problem': ndim_problem,
                'lower_boundary': -100 * np.ones((ndim_problem,)),
                'upper_boundary': 100 * np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 1500*100,
+    options = {'max_function_evaluations': 1500 * 100,
                'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     cep = CEP(problem, options)
     results = cep.optimize()
     print(results['best_so_far_y'])
-    # 4.0
+    # 1.0
     # vs mean 577.76 std 1125.76 (from the original paper)
 
     problem = {'fitness_function': rosenbrock,
                'ndim_problem': ndim_problem,
-               'lower_boundary': -30*np.ones((ndim_problem,)),
-               'upper_boundary': 30*np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 20000*100,
-               'seed_rng': 1,  # undefined in the original paper
+               'lower_boundary': -30 * np.ones((ndim_problem,)),
+               'upper_boundary': 30 * np.ones((ndim_problem,))}
+    options = {'max_function_evaluations': 1500 * 100,
+               'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     cep = CEP(problem, options)
     results = cep.optimize()
     print(results['best_so_far_y'])
-    # 17.835249690659563
-    # vs mean 6.17 std 13.61 (from the original paper)
+    # 75.89000295666568 vs 98.673779
+
+    problem = {'fitness_function': rastrigin,
+               'ndim_problem': ndim_problem,
+               'lower_boundary': -5.12 * np.ones((ndim_problem,)),
+               'upper_boundary': 5.12 * np.ones((ndim_problem,))}
+    options = {'max_function_evaluations': 1500 * 100,
+               'seed_rng': 0,  # undefined in the original paper
+               'sigma': 3.0}
+    cep = CEP(problem, options)
+    results = cep.optimize()
+    print(results['best_so_far_y'])
+    # 37.5086948264173 vs 63.415617
