@@ -54,40 +54,43 @@ class MMES(ES):
        >>> from pypop7.optimizers.es.mmes import MMES
        >>> problem = {'fitness_function': rosenbrock,  # define problem arguments
        ...            'ndim_problem': 200,
-       ...            'lower_boundary': -5 * numpy.ones((200,)),
-       ...            'upper_boundary': 5 * numpy.ones((200,))}
+       ...            'lower_boundary': -5*numpy.ones((200,)),
+       ...            'upper_boundary': 5*numpy.ones((200,))}
        >>> options = {'max_function_evaluations': 500000,  # set optimizer options
        ...            'seed_rng': 2022,
-       ...            'mean': 3 * numpy.ones((200,)),
-       ...            'sigma': 0.1}
+       ...            'mean': 3*numpy.ones((200,)),
+       ...            'sigma': 0.1}  # the global step-size may need to be tuned for better performance
        >>> mmes = MMES(problem, options)  # initialize the optimizer class
        >>> results = mmes.optimize()  # run the optimization process
        >>> # return the number of function evaluations and best-so-far fitness
        >>> print(f"MMES: {results['n_function_evaluations']}, {results['best_so_far_y']}")
-       MMES: 500000, 2.177104401579104e-15
+       MMES: 500000, 7.350414979806526
+
+    For its correctness checking of coding, refer to `this code-based repeatability report
+    <https://tinyurl.com/3ym72w5m>`_ for more details.
 
     Attributes
     ----------
-    n_individuals : `int`
-                    number of offspring (λ: lambda), offspring population size.
-    n_parents     : `int`
-                    number of parents (μ: mu), parental population size.
-    mean          : `array_like`
-                    mean of Gaussian search distribution.
-    sigma         : `float`
-                    mutation strength.
-    m             : `int`
-                    number of candidate direction vectors.
-    c_c           : `float`
-                    learning rate of evolution path.
-    ms            : `int`
-                    mixing strength.
-    c_s           : `float`
-                    learning rate of step-size adaptation.
     a_z           : `float`
                     target significance level.
+    c_c           : `float`
+                    learning rate of evolution path update.
+    c_s           : `float`
+                    learning rate of global step-size adaptation.
     distance      : `int`
                     minimal distance of updating evolution paths.
+    m             : `int`
+                    number of candidate direction vectors.
+    mean          : `array_like`
+                    initial mean of Gaussian search distribution.
+    ms            : `int`
+                    mixing strength.
+    n_individuals : `int`
+                    number of offspring (λ: lambda), aka offspring population size.
+    n_parents     : `int`
+                    number of parents (μ: mu), aka parental population size.
+    sigma         : `float`
+                    final mutation strength.
 
     References
     ----------
@@ -107,7 +110,7 @@ class MMES(ES):
         self.c_c = options.get('c_c', 0.4/np.sqrt(self.ndim_problem))
         self.ms = options.get('ms', 4)  # mixing strength (l)
         # set for paired test adaptation (PTA)
-        self.c_s = options.get('c_s', 0.3)  # learning rate of step-size adaptation
+        self.c_s = options.get('c_s', 0.3)  # learning rate of global step-size adaptation
         self.a_z = options.get('a_z', 0.05)  # target significance level
         # set minimal distance of updating evolution paths (T)
         self.distance = options.get('distance', int(np.ceil(1.0/self.c_c)))
@@ -157,7 +160,7 @@ class MMES(ES):
         y.sort()  # Line 16
         mean_w = np.zeros((self.ndim_problem,))
         for k in range(self.n_parents):  # Line 17
-            mean_w += self._w[k] * x[order[k]]
+            mean_w += self._w[k]*x[order[k]]
         p = self._p_1*p + self._p_2*np.sqrt(self._mu_eff)*(mean_w - mean)/self.sigma  # Line 18
         mean = mean_w  # for Line 17
         if self._n_generations < self.m:
