@@ -2,10 +2,11 @@ from pypop7.optimizers.pso.pso import PSO
 from pypop7.optimizers.pso.spso import SPSO
 from pypop7.optimizers.pso.spsol import SPSOL
 from pypop7.optimizers.pso.clpso import CLPSO
+from pypop7.optimizers.pso.ipso import IPSO
 from pypop7.optimizers.pso.ccpso2 import CCPSO2
 
 
 __all__ = [PSO,  # base (abstract) class
            SPSO, SPSOL,  # standard and canonical versions
            CLPSO,  # competitors for medium- and small-scale black-box problems
-           CCPSO2]  # variants for large-scale black-box optimization
+           IPSO, CCPSO2]  # variants for large-scale black-box optimization
