@@ -10,9 +10,9 @@ class CCPSO2(PSO):
 
     .. note:: `CCPSO2` employs the popular `cooperative coevolution <https://tinyurl.com/57wzdrhm>`_ framework to
        extend PSO for large-scale black-box optimization (LSBBO) with *random grouping/partitioning*. However, it
-       may suffer from **performance degradation** on *non-separable* functions (particularly ill-conditioned), since
-       its axis-parallel decomposition strategy (see the classical **coordinate descent** from the mathematical
-       programming community for detailed mathematical explanation).
+       may suffer from **performance degradation** on *non-separable* functions (particularly ill-conditioned),
+       owing to its axis-parallel decomposition strategy (see the classical **coordinate descent** from the
+       mathematical programming community for detailed mathematical explanation).
 
     Parameters
     ----------
@@ -25,17 +25,17 @@ class CCPSO2(PSO):
     options : dict
               optimizer options with the following common settings (`keys`):
                 * 'max_function_evaluations' - maximum of function evaluations (`int`, default: `np.Inf`),
-                * 'max_runtime'              - maximal runtime (`float`, default: `np.Inf`),
+                * 'max_runtime'              - maximal runtime to be allowed (`float`, default: `np.Inf`),
                 * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`);
               and with the following particular settings (`keys`):
-                * 'n_individuals' - swarm (population) size, number of particles (`int`, default: `30`),
+                * 'n_individuals' - swarm (population) size, aka number of particles (`int`, default: `30`),
                 * 'p'             - probability of using Cauchy sampling distribution (`float`, default: `0.5`),
                 * 'group_sizes'   - a pool of candidate dimensions for grouping (`list`, default:
                   `[2, 5, 10, 50, 100, 250]`).
 
     Examples
     --------
-    Use the PSO optimizer `CCPSO2` to minimize the well-known test function
+    Use the optimizer `CCPSO2` to minimize the well-known test function
     `Rosenbrock <http://en.wikipedia.org/wiki/Rastrigin_function>`_:
 
     .. code-block:: python
@@ -48,22 +48,25 @@ class CCPSO2(PSO):
        ...            'ndim_problem': 500,
        ...            'lower_boundary': -5 * numpy.ones((500,)),
        ...            'upper_boundary': 5 * numpy.ones((500,))}
-       >>> options = {'max_function_evaluations': 500000,  # set optimizer options
+       >>> options = {'max_function_evaluations': 1000000,  # set optimizer options
        ...            'seed_rng': 2022}
        >>> ccpso2 = CCPSO2(problem, options)  # initialize the optimizer class
        >>> results = ccpso2.optimize()  # run the optimization process
        >>> # return the number of function evaluations and best-so-far fitness
        >>> print(f"CCPSO2: {results['n_function_evaluations']}, {results['best_so_far_y']}")
-       CCPSO2: 500000, 874.6603420601381
+       CCPSO2: 1000000, 1150.0205163111475
+
+    For its correctness checking of coding, refer to `this code-based repeatability report
+    <https://tinyurl.com/bdfywpyx>`_ for more details.
 
     Attributes
     ----------
-    n_individuals : `int`
-                    swarm (population) size, number of particles.
-    p             : `float`
-                    probability of using Cauchy sampling distribution.
     group_sizes   : `list`
                     a pool of candidate dimensions for grouping.
+    n_individuals : `int`
+                    swarm (population) size, aka number of particles.
+    p             : `float`
+                    probability of using Cauchy sampling distribution.
 
     References
     ----------
@@ -71,6 +74,12 @@ class CCPSO2(PSO):
     Cooperatively coevolving particle swarms for large scale optimization.
     IEEE Transactions on Evolutionary Computation, 16(2), pp.210-224.
     https://ieeexplore.ieee.org/document/5910380/
+
+    Potter, M.A. and De Jong, K.A., 1994, October.
+    A cooperative coevolutionary approach to function optimization.
+    In International Conference on Parallel Problem Solving from Nature (pp. 249-257).
+    Springer, Berlin, Heidelberg.
+    https://link.springer.com/chapter/10.1007/3-540-58484-6_269
     """
     def __init__(self, problem, options):
         PSO.__init__(self, problem, options)
@@ -79,8 +88,7 @@ class CCPSO2(PSO):
         self.group_sizes = options.get('group_sizes', [2, 5, 10, 50, 100, 250])
         assert np.alltrue(np.array(self.group_sizes) <= self.ndim_problem)
         self._indices = np.arange(self.ndim_problem)  # indices of all dimensions
-        self._s_index = 0
-        self._s = self.group_sizes[self._s_index]  # dimension to be optimized by each swarm
+        self._s = self.rng_optimization.choice(self.group_sizes)  # dimension to be optimized by each swarm
         self._k = int(np.ceil(self.ndim_problem/self._s))  # number of swarms
         self._improved = True
         self._best_so_far_y = self.best_so_far_y
@@ -107,10 +115,13 @@ class CCPSO2(PSO):
         ring = [left, i, right]
         return p_x[ring[int(np.argmin(p_y[j, ring]))], indices]
 
-    def iterate(self, v=None, x=None, y=None, p_x=None, p_y=None, n_x=None, args=None, fitness=None):
+    def iterate(self, x=None, y=None, p_x=None, p_y=None, n_x=None, args=None, fitness=None):
         if self._improved is False:
-            self._s_index += 1
-            self._s = self.group_sizes[np.minimum(self._s_index, len(self.group_sizes) - 1)]
+            candidates = self.rng_optimization.choice(self.group_sizes, size=(2,), replace=False)
+            if self._s == candidates[0]:  # to ensure that a different value is chosen
+                self._s = candidates[1]
+            else:
+                self._s = candidates[0]
             self._k = int(np.ceil(self.ndim_problem/self._s))
             self.rng_optimization.shuffle(self._indices)  # random permutation
             y = np.empty((self._k, self.n_individuals))  # fitness for all individuals of all swarms
@@ -125,7 +136,7 @@ class CCPSO2(PSO):
             if self.saving_fitness:
                 fitness.extend(y.flatten())
             p_y = np.copy(y)
-        self._improved = False
+        self._improved, self._best_so_far_y = False, self.best_so_far_y
         for j in range(self._k):  # for each swarm
             for i in range(self.n_individuals):  # for each individual
                 if self._check_terminations():
@@ -138,31 +149,27 @@ class CCPSO2(PSO):
                     p_x[i, indices], p_y[j, i] = cv[indices], y[j, i]
                 if y[j, i] < self._best_so_far_y:
                     self._improved, self._best_so_far_y = True, y[j, i]
+            for i in range(self.n_individuals):  # for each individual
+                indices = self._indices[np.arange(j*self._s, (j + 1)*self._s)]
                 n_x[i, indices] = self._ring_topology(p_x, p_y, j, i, indices)
         for j in range(self._k):  # for each swarm
             for i in range(self.n_individuals):  # for each individual
                 indices = self._indices[np.arange(j*self._s, (j + 1)*self._s)]
                 std = np.abs(p_x[i, indices] - n_x[i, indices])
-                if self.rng_optimization.random() <= self.p:  # sampling from Cauchy distribution
-                    x[i, indices] = p_x[i, indices] + cauchy.rvs(
-                        scale=std, random_state=self.rng_optimization)
-                else:  # sampling from Gaussian distribution
-                    x[i, indices] = n_x[i, indices] + std*self.rng_optimization.standard_normal(
-                        size=(len(indices),))
+                for jj, ii in enumerate(indices):
+                    if self.rng_optimization.random() <= self.p:  # sampling from Cauchy distribution
+                        x[i, ii] = p_x[i, ii] + std[jj]*cauchy.rvs(random_state=self.rng_optimization)
+                    else:  # sampling from Gaussian distribution
+                        x[i, ii] = n_x[i, ii] + std[jj]*self.rng_optimization.standard_normal()
+                x[i, indices] = np.clip(x[i, indices], self.lower_boundary[indices], self.upper_boundary[indices])
         self._n_generations += 1
         return x, y, p_x, p_y, n_x
 
     def optimize(self, fitness_function=None, args=None):
         fitness = Optimizer.optimize(self, fitness_function)
         x, y, p_x, p_y, n_x = self.initialize(args)
-        if self.saving_fitness:
-            fitness.extend(y[0])
-        self._print_verbose_info(y)
-        while True:
-            x, y, p_x, p_y, n_x = self.iterate(None, x, y, p_x, p_y, n_x, args, fitness)
-            if self.saving_fitness:
-                fitness.extend(y.flatten())
-            if self._check_terminations():
-                break
-            self._print_verbose_info(y)
+        self._print_verbose_info(fitness, y[0])
+        while not self.termination_signal:
+            x, y, p_x, p_y, n_x = self.iterate(x, y, p_x, p_y, n_x, args, fitness)
+            self._print_verbose_info(fitness, y.flatten())
         return self._collect_results(fitness)
